@@ -30,6 +30,7 @@ pub fn render(content: &String) -> Result<String, ()> {
     let syntax_highlighter = self::syntax_highlighter::SyntaxHighlighter::new();
 
     let mut u16_content = into_v16(content);
+    u16_content = escape_backslashes(&u16_content);
     u16_content = escape_htmls(&u16_content);
 
     let mut lines = code_to_lines(&u16_content);
@@ -50,7 +51,7 @@ pub fn render(content: &String) -> Result<String, ()> {
     lines = merge_blockquote(&lines);
 
     let mut result = render_lines(&lines);
-    result = escape_backslashes(&result);
+    result = render_backslash_escape(&result);
 
     Ok(String::from_utf16_lossy(&result))
 }
\ No newline at end of file
