@@ -1,6 +1,6 @@
 use crate::consts::*;
 use crate::utils::into_v16;
-use crate::markdown::escape::prevent_backslash_escape;
+use crate::markdown::escape::undo_backslash_escape;
 use crate::markdown::inline::link::render_link;
 use crate::markdown::inline::tag::render_tag;
 
@@ -18,7 +18,7 @@ pub fn render_code_spans(content: &Vec<u16>) -> Vec<u16> {
             if is_inside_code {
                 result.push(vec![
                     into_v16("<code class=\"short\">"),
-                    prevent_backslash_escape(&content[last_index..ind].to_vec()),
+                    undo_backslash_escape(&content[last_index..ind].to_vec()),
                     into_v16("</code>"),
                 ].concat());
             }
