@@ -2,7 +2,7 @@ use crate::consts::*;
 use crate::markdown::icon::get_icon;
 use crate::markdown::line::{Line, LineType};
 use crate::markdown::colors::{COLORS, COLOR_NAMES};
-use crate::utils::{get_bracket_end_index, lowercase};
+use crate::utils::{get_bracket_end_index, lowercase, into_v16};
 use std::str::FromStr;
 
 
@@ -97,28 +97,28 @@ fn parse_tag(content: &Vec<u16>, index: usize) -> Result<Vec<u16>, ()> {
     // <span class="font_big">
     if is_color_name(&content) || is_size_name(&content) {
         return Ok(vec![
-            vec![U16_LESS_THAN, U16_SMALL_S, U16_SMALL_P, U16_SMALL_A, U16_SMALL_N, U16_SPACE, U16_SMALL_C, U16_SMALL_L, U16_SMALL_A, U16_SMALL_S, U16_SMALL_S, U16_EQUAL, U16_DOUBLE_QUOTE, U16_SMALL_F, U16_SMALL_O, U16_SMALL_N, U16_SMALL_T, U16_UNDERBAR],
+            into_v16("<span class=\"font_"),
             content,
-            vec![U16_DOUBLE_QUOTE, U16_GREATER_THAN]
+            into_v16("\">")
         ].concat());
     }
 
     // <div class="align_center">
     if is_alignment_name(&content) {
         return Ok(vec![
-            vec![U16_LESS_THAN, U16_SMALL_D, U16_SMALL_I, U16_SMALL_V, U16_SPACE, U16_SMALL_C, U16_SMALL_L, U16_SMALL_A, U16_SMALL_S, U16_SMALL_S, U16_EQUAL, U16_DOUBLE_QUOTE, U16_SMALL_A, U16_SMALL_L, U16_SMALL_I, U16_SMALL_G, U16_SMALL_N, U16_UNDERBAR],
+            into_v16("<div class=\"align_"),
             content,
-            vec![U16_DOUBLE_QUOTE, U16_GREATER_THAN]
+            into_v16("\">")
         ].concat());
     }
 
     // <div class="box">
     if is_box_name(&content) {
-        return Ok(vec![U16_LESS_THAN, U16_SMALL_D, U16_SMALL_I, U16_SMALL_V, U16_SPACE, U16_SMALL_C, U16_SMALL_L, U16_SMALL_A, U16_SMALL_S, U16_SMALL_S, U16_EQUAL, U16_DOUBLE_QUOTE, U16_SMALL_B, U16_SMALL_O, U16_SMALL_X, U16_DOUBLE_QUOTE, U16_GREATER_THAN]);
+        return Ok(into_v16("<div class=\"box\">"));
     }
 
     if is_blank_name(&content) {
-        return Ok(vec![U16_AMPERSAND, U16_SMALL_N, U16_SMALL_B, U16_SMALL_S, U16_SMALL_P, U16_SEMI_COLON]);
+        return Ok(into_v16("&nbsp;"));
     }
 
     if is_icon(&content) {
@@ -130,14 +130,23 @@ fn parse_tag(content: &Vec<u16>, index: usize) -> Result<Vec<u16>, ()> {
 
     }
 
+    if is_char(&content) {
+
+        match parse_char(&content) {
+            Some(s) => {return Ok(s);}
+            _ => {}
+        }
+
+    }
+
     if content[0] == U16_SLASH {
 
         if is_color_name(&content[1..]) || is_size_name(&content[1..]) {
-            return Ok(vec![U16_LESS_THAN, U16_SLASH, U16_SMALL_S, U16_SMALL_P, U16_SMALL_A, U16_SMALL_N, U16_GREATER_THAN]);
+            return Ok(into_v16("</span>"));
         }
 
         if is_alignment_name(&content[1..]) || is_box_name(&content[1..]) {
-            return Ok(vec![U16_LESS_THAN, U16_SLASH, U16_SMALL_D, U16_SMALL_I, U16_SMALL_V, U16_GREATER_THAN]);
+            return Ok(into_v16("</div>"));
         }
 
     }
@@ -145,23 +154,20 @@ fn parse_tag(content: &Vec<u16>, index: usize) -> Result<Vec<u16>, ()> {
     Err(())
 }
 
-// TODO: make a `color` module
-// define all colors there
-// `color_names.contains(string)` would be much better!
 fn is_color_name(string: &[u16]) -> bool {
     COLOR_NAMES.contains(&string.to_vec())
 }
 
 fn is_size_name(string: &[u16]) -> bool {
-    string == &vec![U16_SMALL_B, U16_SMALL_I, U16_SMALL_G] ||
-    string == &vec![U16_SMALL_S, U16_SMALL_M, U16_SMALL_A, U16_SMALL_L, U16_SMALL_L] ||
-    string == &vec![U16_SMALL_M, U16_SMALL_E, U16_SMALL_D, U16_SMALL_I, U16_SMALL_U, U16_SMALL_M]
+    string == &into_v16("big") ||
+    string == &into_v16("small") ||
+    string == &into_v16("medium")
 }
 
 fn is_alignment_name(string: &[u16]) -> bool {
-    string == &vec![U16_SMALL_L, U16_SMALL_E, U16_SMALL_F, U16_SMALL_T] ||
-    string == &vec![U16_SMALL_R, U16_SMALL_I, U16_SMALL_G, U16_SMALL_H, U16_SMALL_T] ||
-    string == &vec![U16_SMALL_C, U16_SMALL_E, U16_SMALL_N, U16_SMALL_T, U16_SMALL_E, U16_SMALL_R]
+    string == &into_v16("left") ||
+    string == &into_v16("right") ||
+    string == &into_v16("center")
 }
 
 fn is_box_name(string: &[u16]) -> bool {
@@ -178,30 +184,6 @@ fn is_icon(string: &[u16]) -> bool {
     string.len() > 5 && string[0] == U16_SMALL_I && string[1] == U16_SMALL_C && string[2] == U16_SMALL_O && string[3] == U16_SMALL_N && string[4] == U16_EQUAL
 }
 
-// `[[a = b, c = d, e = f]]` -> vec![(`a`, `b`), (`c`, `d`), (`e`, `f`)]
-fn parse_arguments(content: &[u16]) -> Vec<(Vec<u16>, Vec<u16>)> {  // Vec<(key, value)>
-    content.split(
-        |c|
-        *c == U16_COMMA
-    ).filter_map(
-        |arg| {
-            let arg_split = arg.split(
-                |c|
-                *c == U16_EQUAL
-            ).map(
-                |word|
-                word.to_vec()
-            ).collect::<Vec<Vec<u16>>>();
-
-            if arg_split.len() == 2 {
-                Some((arg_split[0].clone(), arg_split[1].clone()))
-            } else {
-                None
-            }
-        }
-    ).collect()
-}
-
 fn parse_icon(content: &[u16]) -> Option<Vec<u16>> {
 
     let mut curr_icon = None;
@@ -213,15 +195,15 @@ fn parse_icon(content: &[u16]) -> Option<Vec<u16>> {
     // I'm not raising an error for that
     for (key, value) in args.iter() {
 
-        if key == &vec![U16_SMALL_I, U16_SMALL_C, U16_SMALL_O, U16_SMALL_N] {
+        if key == &into_v16("icon") {
             curr_icon = Some(value.clone());
         }
 
-        else if key == &vec![U16_SMALL_S, U16_SMALL_I, U16_SMALL_Z, U16_SMALL_E] {
+        else if key == &into_v16("size") {
             curr_size = Some(value.clone());
         }
 
-        else if key == &vec![U16_SMALL_C, U16_SMALL_O, U16_SMALL_L, U16_SMALL_O, U16_SMALL_R] {
+        else if key == &into_v16("color") {
             curr_color = Some(value.clone());
         }
 
@@ -247,7 +229,7 @@ fn parse_icon(content: &[u16]) -> Option<Vec<u16>> {
     };
 
     let curr_color = match curr_color {
-        None => vec![U16_SMALL_W, U16_SMALL_H, U16_SMALL_I, U16_SMALL_T, U16_SMALL_E],
+        None => into_v16("white"),
         Some(s) => if is_color_name(&s) {
             s.clone()
         } else {
@@ -261,4 +243,50 @@ fn parse_icon(content: &[u16]) -> Option<Vec<u16>> {
     };
 
     get_icon(&curr_icon, curr_size, r, g, b)
+}
+
+// if true, it's possibly a valid char
+// if not, it can never be an char
+fn is_char(string: &[u16]) -> bool {
+    string.len() > 5 && string[0] == U16_SMALL_C && string[1] == U16_SMALL_H && string[2] == U16_SMALL_A && string[3] == U16_SMALL_R && string[4] == U16_EQUAL
+}
+
+fn parse_char(content: &[u16]) -> Option<Vec<u16>> {
+    let args = parse_arguments(content);
+
+    if args.len() != 1 {
+        return None;
+    }
+
+    let num = &args[0].1;
+
+    match u16::from_str(&String::from_utf16_lossy(num)) {
+        Err(_) => None,
+        Ok(n) => Some(into_v16(&format!("&#{};", n) ))
+    }
+
+}
+
+// `[[a = b, c = d, e = f]]` -> vec![(`a`, `b`), (`c`, `d`), (`e`, `f`)]
+fn parse_arguments(content: &[u16]) -> Vec<(Vec<u16>, Vec<u16>)> {  // Vec<(key, value)>
+    content.split(
+        |c|
+        *c == U16_COMMA
+    ).filter_map(
+        |arg| {
+            let arg_split = arg.split(
+                |c|
+                *c == U16_EQUAL
+            ).map(
+                |word|
+                word.to_vec()
+            ).collect::<Vec<Vec<u16>>>();
+
+            if arg_split.len() == 2 {
+                Some((arg_split[0].clone(), arg_split[1].clone()))
+            } else {
+                None
+            }
+        }
+    ).collect()
 }
\ No newline at end of file
